@@ -1,16 +1,16 @@
-use crate::api_info;
-use crate::Context;
-use crate::error::ApiResult;
 use crate::api::ApiRequest;
+use crate::api_info;
+use crate::error::ApiResult;
+use crate::Context;
 
 use super::ApiRequestBuilder;
 
+/// User related APIs collection
 pub struct User {
     ctx: Context,
     uid: String,
 }
 
-
 impl User {
     pub fn new<T: ToString>(n: &Context, uid: T) -> Self {
         Self {
@@ -20,10 +20,10 @@ impl User {
     }
 
     fn rb(&self) -> ApiRequestBuilder {
-        self.ctx.req_build()
-            .api(api_info::user::get)
+        self.ctx.req_build().api(api_info::user::get)
     }
 
+    /// Get user basic info.
     pub fn get_info(&self) -> ApiResult<ApiRequest> {
         self.rb()
             .path("info/info")
@@ -31,19 +31,21 @@ impl User {
             .bufferable()
     }
 
+    /// Fetch user's upload video list.
     pub fn video_list(&self, page_no: i32) -> ApiResult<ApiRequest> {
         let pn = page_no.to_string();
         self.rb()
             .path("info/video")
-            .query(&[
-                   ("mid", &self.uid),
-                   ("pn", &pn),
-            ])
-            .query(&[
-                   ("tid", "0"),
-                   ("ps", "30"),
-                   ("order", "pubdate"),
-            ])
+            .query(&[("mid", &self.uid), ("pn", &pn)])
+            .query(&[("tid", "0"), ("ps", "30"), ("order", "pubdate")])
+            .bufferable()
+    }
+
+    /// Get honorable statistic numbers
+    pub fn stat(&self) -> ApiResult<ApiRequest> {
+        self.rb()
+            .path("info/upstat")
+            .query(&[("mid", &self.uid)])
             .nobuffer()
     }
 }
